==> openshift-model-operator-4.11.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/ServiceCAListFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ServiceCAListFluent<A extends ServiceCAListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ServiceCA item);
    public A setToItems(int index,ServiceCA item);
    public A addToItems(ServiceCA... items);
    public A addAllToItems(Collection<ServiceCA> items);
    public A removeFromItems(ServiceCA... items);
    public A removeAllFromItems(Collection<ServiceCA> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<ServiceCABuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ServiceCA> getItems();
    public List<ServiceCA> buildItems();
    public ServiceCA buildItem(int index);
    public ServiceCA buildFirstItem();
    public ServiceCA buildLastItem();
    public ServiceCA buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ServiceCABuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ServiceCABuilder> predicate);
    public A withItems(List<ServiceCA> items);
    public A withItems(ServiceCA... items);
    public Boolean hasItems();
    public ServiceCAListFluent.ItemsNested<A> addNewItem();
    public ServiceCAListFluent.ItemsNested<A> addNewItemLike(ServiceCA item);
    public ServiceCAListFluent.ItemsNested<A> setNewItemLike(int index,ServiceCA item);
    public ServiceCAListFluent.ItemsNested<A> editItem(int index);
    public ServiceCAListFluent.ItemsNested<A> editFirstItem();
    public ServiceCAListFluent.ItemsNested<A> editLastItem();
    public ServiceCAListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<ServiceCABuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ServiceCAFluent<ServiceCAListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> openshift-model-operator-5.0.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/ServiceCAListFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ServiceCAListFluent<A extends ServiceCAListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ServiceCA item);
    public A setToItems(int index,ServiceCA item);
    public A addToItems(ServiceCA... items);
    public A addAllToItems(Collection<ServiceCA> items);
    public A removeFromItems(ServiceCA... items);
    public A removeAllFromItems(Collection<ServiceCA> items);
    public A removeMatchingFromItems(Predicate<ServiceCABuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ServiceCA> getItems();
    public List<ServiceCA> buildItems();
    public ServiceCA buildItem(int index);
    public ServiceCA buildFirstItem();
    public ServiceCA buildLastItem();
    public ServiceCA buildMatchingItem(Predicate<ServiceCABuilder> predicate);
    public Boolean hasMatchingItem(Predicate<ServiceCABuilder> predicate);
    public A withItems(List<ServiceCA> items);
    public A withItems(ServiceCA... items);
    public Boolean hasItems();
    public ServiceCAListFluent.ItemsNested<A> addNewItem();
    public ServiceCAListFluent.ItemsNested<A> addNewItemLike(ServiceCA item);
    public ServiceCAListFluent.ItemsNested<A> setNewItemLike(int index,ServiceCA item);
    public ServiceCAListFluent.ItemsNested<A> editItem(int index);
    public ServiceCAListFluent.ItemsNested<A> editFirstItem();
    public ServiceCAListFluent.ItemsNested<A> editLastItem();
    public ServiceCAListFluent.ItemsNested<A> editMatchingItem(Predicate<ServiceCABuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ServiceCAFluent<ServiceCAListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
